@@ -4,6 +4,9 @@ __all__ = ['filter', 'Censor', 'Remove']
 import json
 import random
 
+from setuptools import pkg_resources
+bleep_it_data = pkg_resources.resource_filename("<bleep-it>", "data.json") 
+
 
 class Censor:
 	def __init__(self, style: str | list[str] | None = '*') -> None:
@@ -48,7 +51,7 @@ def get_banned_words(strickness: int) -> list[str]:
 		list[str] - A list of all the words to be detected.
 	"""
 
-	with open('data.json', 'r') as f:
+	with open(bleep_it_data, 'r') as f:
 		data = json.loads(f.read())
 
 	banned_words = []
